import datetime

class myMoon:
    def __init__(self):
        self.lunartime = 29.530588853

    def get_julian_date(self):
        date = None
        # If no date is provided, use the current date and time
        if date is None:
            date = datetime.datetime.now()

        # Convert the date to a timestamp in milliseconds
        timestamp = date.timestamp() * 1000

        # Calculate the timezone offset in minutes
        if date.utcoffset():
            timezone_offset = date.utcoffset().total_seconds() // 60
        else:
            timezone_offset = 0

        # Calculate the Julian date and return it
        julian_date = (timestamp / 86400000) - (timezone_offset / 1440) + 2440587.5
        return julian_date





    def get_lunar_age(self):
        percent = self.get_lunar_age_percent()
        age = percent * self.lunartime
        return age


    def get_lunar_age_percent(self):
        julian_date = self.get_julian_date()
        tmp = (julian_date - 2451550.1) / self.lunartime
        percent = self.normalize(tmp)
        return percent


    def normalize(self,value):
        value = value - int(value)
        if value < 0:
            value = value + 1
        return value

    def get_lunar_phase(self):
        age = self.get_lunar_age()
        if age < 1.84566:
            return "new moon"
        elif age < 5.53699:
            return "waxing crescent"
        elif age < 9.22831:
            return "first quarter"
        elif age < 12.91963:
            return "waxing gibbous"
        elif age < 16.61096:
            return "full"
        elif age < 20.30228:
            return 'waning gibbous'
        elif age < 23.99361:
            return "third quarter"
        elif age < 27.68493:
            return "waning crescent"

        # in case it has just finished it's cycle
        return "new"





import math
import datetime
# start by calculating julian date
class Sun:
        def get_julian_date(self):
                date = None
                # If no date is provided, use the current date and time
                if date is None:
                    date = datetime.datetime.now()

                # Convert the date to a timestamp in milliseconds
                timestamp = date.timestamp() * 1000

                # Calculate the timezone offset in minutes
                if date.utcoffset():
                    timezone_offset = date.utcoffset().total_seconds() // 60
                else:
                    timezone_offset = 0

                # Calculate the Julian date and return it
                julian_date = (timestamp / 86400000) - (timezone_offset / 1440) + 2440587.5
                return julian_date

        def solardistance(self):
                 juliandate = self.get_julian_date()
                 # days since greenwich noon
                 n = juliandate - 2451545 
                 # positions
                 meanlong = 280.460 + 0.9856474 * n
                 # g is mean anomaly 
                 g = 357.528 + 0.9856003 * n
                 tmp = math.cos(g)
                 temptwo = math.cos(2*g)
                 # solar distance is in astronomical units
                 solardistance = 1.00014 - 0.01671*tmp - 0.00014*temptwo
                 return solardistance * 92,955,807.3 # miles
  



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='lunastro',
    version='0.0.1',
    author='Siddhu Pendyala',
    author_email='elcientifico.pendyala@hotmail.com',
    description='python package for lunar and solar information',
    long_description = long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/PyndyalaCoder/lunastro',
    project_urls = {
        "Bug Tracker": "https://github.com/PyndyalaCoder/lunastro/issues"
    },
    license='MIT',
    packages=['lunastro'],
    install_requires=['requests'],
)
